==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik op het systeemvakpictogram
of druk nogmaals op de sneltoets om te stoppen</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Scherm vastleggen</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Het opslaan is mislukt. Sla het op in je persoonlijke map.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>De schermfoto is genomen</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Gebied selecteren</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Klembord</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Bezig met opslaan van schermopname...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>De opname moet worden gestopt omdat vensteranimaties moeten worden uitgeschakeld</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>De opname is afgerond</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Het scherm wordt over %1 seconden vastgelegd</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Voer hier tekst in</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Starten/Schermfoto</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afsluiten/Opslaan</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Tekenen</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Afmetingen aanpassen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inleiding</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Schermfoto van venster</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Vertraging gebruiken</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Schermfoto van volledig scherm</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechthoek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Potlood</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Verhogen (bovenkant)</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Verhogen (onderkant)</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Verbreden (links)</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Verbreden (rechts)</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Verlagen (bovenkant)</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Verlagen (onderkant)</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Versmallen (links)</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Versmallen (rechts)</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Toetsaanslag</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Cursor</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Vervagen</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaïek</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Geluid aan</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfoon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systeemgeluid</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Geluid uit</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Toetsaanslagen tonen</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Toetsaanslagen verbergen</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam aan</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam uit</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Muisklikken tonen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechthoek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pijl</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Potlood</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Opslaan op/in</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Andere map</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Klembord</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Cursor vastleggen</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Cursor vastleggen</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Verhoog de resolutie van het opnamegebied naar %1*%2 voor een betere opname</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Opnames</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik op het systeemvakpictogram
of druk nogmaals op de sneltoets om te stoppen</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Scherm niet draaien tijdens opname</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Scherm vastleggen</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Het opslaan is mislukt. Sla het op in je persoonlijke map.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>De schermfoto is genomen</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Gebied selecteren</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Klembord</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Bezig met opslaan van schermopname...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>De opname moet worden gestopt omdat vensteranimaties moeten worden uitgeschakeld</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>De schermfoto is opgeslagen in het album</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>De schermfoto kan niet worden gemaakt.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollende schermfoto</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>De opname is afgerond</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Het scherm wordt over %1 seconden vastgelegd</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Verkrijg hulp.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>De scrollende schermfoto kan niet worden gemaakt.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>De onderkant van het scrollgebied is bereikt</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>De maximale lengte is bereikt</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>het vastleggebied aan te passen</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scroll met je muis of klik om een scrollende schermfoto te maken</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Verlaag de scrollsnelheid</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Ongeldig gebied; klik om het</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Voer hier tekst in</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Starten/Schermfoto</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afsluiten/Opslaan</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Afmetingen aanpassen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inleiding</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Schermfoto van venster</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Vertraging gebruiken</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Schermfoto van volledig scherm</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechthoek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Potlood</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Verhogen (bovenkant)</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Verhogen (onderkant)</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Verbreden (links)</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Verbreden (rechts)</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Verlagen (bovenkant)</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Verlagen (onderkant)</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Versmallen (links)</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Versmallen (rechts)</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Toetsaanslag</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Tekst extraheren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollende schermfoto</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Schermfoto&apos;s vastmaken</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Vervagen</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaïek</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Geluid aan</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfoon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systeemgeluid</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Geluid uit</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Toetsaanslagen tonen</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Toetsaanslagen verbergen</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam aan</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam uit</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Muisklikken tonen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechthoek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pijl</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Potlood</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Opslaan op/in</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Andere map</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Klembord</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Cursor vastleggen</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Cursor vastleggen</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Tekst extraheren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollende schermfoto</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Schermfoto&apos;s vastmaken</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Verhoog de resolutie van het opnamegebied naar %1*%2 voor een betere opname</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Schermopname wordt momenteel niet ondersteund</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
</TS>
